@@ -18,7 +18,7 @@ mod helper;
 
 #[derive(Clone)]
 pub struct Kubectl {
-    pub client: kube::Client,
+    client: kube::Client,
 }
 
 impl Kubectl {
@@ -28,8 +28,8 @@ impl Kubectl {
             .map(|client| Self { client })
     }
 
-    pub fn client(&self) -> &kube::Client {
-        &self.client
+    pub fn client(&self) -> kube::Client {
+        self.client.clone()
     }
 
     pub async fn apiserver_version(&self) -> kube::Result<apimachinery::pkg::version::Info> {
