@@ -28,7 +28,7 @@ impl super::Kubectl {
         T: kube::Resource,
         <T as kube::Resource>::DynamicType: Default,
     {
-        let client = self.client.clone();
+        let client = self.client();
         api::Api::<T>::all(client)
     }
 
@@ -37,7 +37,7 @@ impl super::Kubectl {
         T: kube::Resource,
         <T as kube::Resource>::DynamicType: Default,
     {
-        let client = self.client.clone();
+        let client = self.client();
         api::Api::<T>::default_namespaced(client)
     }
 
@@ -46,7 +46,7 @@ impl super::Kubectl {
         T: kube::Resource,
         <T as kube::Resource>::DynamicType: Default,
     {
-        let client = self.client.clone();
+        let client = self.client();
         api::Api::<T>::namespaced(client, namespace)
     }
 
