@@ -18,8 +18,9 @@
 #![warn(unused)]
 #![deny(warnings)]
 
+pub use k8s_openapi::api::apps::v1 as appsv1;
 pub use k8s_openapi::api::core::v1 as corev1;
-use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1 as apiextensionsv1;
+pub use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1 as apiextensionsv1;
 
 pub use kubectl::Kubectl;
 
